@@ -83,7 +83,10 @@ async def execute_model(
             response_compression_algorithm=compression_algorithm,
         )
 
-        return {
+        results = {
             output["name"]: results.as_numpy(output["name"])
             for output in results._result["outputs"]
         }
+
+        results['__response__'] = results.get_response()
+        return results
